### Information about this plugin

This plugin is an All-in-One approach developed by iubenda: it lets you automate the implementation of ePrivacy (Cookie Law) and GDPR requirements by providing a fully customizable cookie banner, blocking scripts, and by managing all aspects of cookie consent.

This plugin drastically reduces the need for direct interventions in the code of the site by integrating with iubenda’s Cookie Solution. It provides a fully customizable cookie banner, dynamically generates a cookie policy to match the services in use on your site (https://www.iubenda.com/en/help/19004), and, fully manages cookie-related consent – including the blocking of the most common widgets and third-party cookies before consent is received – in order to comply with the GDPR and ePrivacy.

Key features:

* The plugin automatically inserts the iubenda code in the head of every page of the site
* Allows you to automatically or manually block scripts that can install cookies prior to consent, without the need of direct intervention on the code
* Asynchronously re-activates cookie scripts once consent is collected.
* Handles the display of the cookie banner and cookie policy, allowing you to fully customize the banner to match the look and colors of your site if needed
* Saves user preferences about the use of cookies and displays a clean page (without banner) to users who have already provided their consent
* Integrates with IAB’s Transparency and Consent Framework (https://www.iubenda.com/en/help/7440) (TCF)
* Features an easy-to-use interface for entering custom scripts and iframes
* Detects bots/spiders and serves them a clean page so that your SEO efforts are never compromised

The plugin is currently capable of automatically detecting and blocking the following scripts:

* AdRoll
* AddThis widgets
* Bing
* Codepen
* Criteo
* Disqus
* Elevio
* Facebook Comments
* Facebook widgets
* Freshchat
* Google AdSense
* Google Analytics
* Google Maps
* Google ReCaptcha
* Google Site Search
* Google Tag Manager
* Google oAuth
* Google+ widgets
* Headway
* Instagram widgets
* Kissmetrics
* Linkedin widgets
* Mixpanel
* Neodata
* Olark
* Optimizely
* Outbrain
* PayPal widgets
* Pingdom
* Pinterest widgets
* Segment
* ShareThis widgets
* Twitter widgets
* Uservoice
* Vimeo
* YouTube

### Some background information

If you potentially have any European users, you must comply with laws like the GDPR (https://www.iubenda.com/en/help/5428) and ePrivacy (https://www.iubenda.com/en/help/6293). These laws are precise in their requirements and technical implementation can be pretty complicated. We’ve tried to make this process as painless as possible for website and app owners with our suite of compliance software solutions. Our Cookie Solution plugin simplifies and manages these compliance requirements within a few clicks. This extension works with the iubenda Cookie Solution (https://www.iubenda.com/en/cookie-solution).

Which languages does iubenda work in currently?

* English
* Italian
* French
* Spanish
* Portuguese (Brazilian)
* German
* Dutch
* Russian

### Compatibility

The Joomla! plugin is compatible with all versions of Joomla! starting from 2.5 (included)

### Installation and activation
- Access the Admin panel (http://example.com/admin123/) and log in
- Click on the "Install" located in the "Extensions -> Manage" menu that is on the top of the screen in the Admin panel
- Navigate to "Modules and Services" menu item
- Drag and drop file zipped iubenda plugin file or click "Browse for file" and select the iubenda file from your computer.

### Configuration
- Click on the item "Extensions" located in the top menu and select "Plugins"
- After the plugin is successfully uploaded enter the "Configuration" of the iubenda Cookie Solution
- Search "iubenda" and click on the plugin name
- Configure the extensions by copying the javascript code from your iubenda.com account
- At this stage you will find all the instructions directly inside the plugin page

### Use
Once configured, the plugin will begin to show the banner on which your cookie policy will be shown/linked to users that visit your site for the first time without the need for any other further configurations. Moreover, the plugin will recognize and automatically block the cookies installed by all the YouTube video players and social widgets - like the Facebook Like button - present on your site.

Important note: our Joomla plugin blocks all scripts by Facebook, Twitter, G+, YouTube iframes automatically that are generated on the server side (therefore returned by PHP by Joomla). Scripts that are inserted into the page via Javascript after the loading process of that page aren't and can't be blocked automatically; The other scripts which aren't yet automatically blocked - and that install cookies which require blocking prior to their installation - can be "wrapped" as illustrated in this help post https://www.iubenda.com/en/help/1229

### Manual Use

How to make the plugin manually work for a Facebook button?

    <!--IUB-COOKIE-BLOCK-START-->
    <script>
    (function(d, s, id) {
     var js, fjs = d.getElementsByTagName(s)[0];
     if (d.getElementById(id)) return;
     js = d.createElement(s); js.id = id;
     js.src = "//connect.facebook.net/en_US/sdk.js#xfbml=1&version=v2.3&appId=808061959224601";
     fjs.parentNode.insertBefore(js, fjs);
    }(document, 'script', 'facebook-jssdk'));
    </script>
    <!--IUB-COOKIE-BLOCK-END-->

If there are HTML / IMG / IFRAME elements, you need to proceed in this way:

    <!--IUB-COOKIE-BLOCK-START-->
          <iframe src="...
          <img src="...
    <!--IUB-COOKIE-BLOCK-END-->

### Changelog

##### 1.3.1
* Fix: Google Tag manager per-purpose category

##### 1.3.0
* Tweak: Add Google GPT to per-purpose blocking support

##### 1.2.9
* Security Fix: limit url sanitize to http protocols

##### 1.2.8
* Fix: AddThis per-purpose category

##### 1.2.7
* New: Per-purpose script blocking support
* New: "Reject" button support

##### 1.2.6
* Tweak: Simple HTML Dom PHP class update to 1.9
* Tweak: Improved Google Tag Manager script blocking

##### 1.2.5
* New: Introducing a way to skip specific script parsing
* Fix: Improved handling of iubenda script HTML
* Tweak: Support links update

##### 1.2.4
* New: Option to block custom scripts and iframes
* Tweak: Update and extend the list of blocked scripts including Google Site Search, Google oAuth, Linkedin widgets, PayPal widgets, Freshchat, Uservoice
, AdRoll, Olark, Segment, Kissmetrics, Mixpanel, Pingdom, Bing and Elevio

##### 1.2.3
* Tweak: Update and extend the list of blocked scripts including Pinterest, AddThis, Disqus, Optimizely, Neodata, Criteo, Outbrain, Headway and Codepen
* Tweak: Interface improvements

##### 1.2.2
* Tweak: Update and unify iubenda parsing engine

##### 1.2.1
* Tweak: iubenda faster class regex update

##### 1.0.0
* Initial release

### License

This project is licensed under the GPl 3 license.
